@@ -1,26 +1,17 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import abc
-import io
 import os.path
 import re
+from urllib.parse import urlparse
 
 import msgfy
 import nbformat
-import six
-from six.moves.urllib.parse import urlparse
-
-
-try:
-    import simplejson as json
-except ImportError:
-    import json
+import retryrequests
+import simplejson as json
 
 
 KEY_VALUE_TABLE = "kv"
@@ -37,57 +28,36 @@ def is_ipynb_url(url):
 
 
 def _schema_not_found_error_handler(e):
-    if re.search("No such file or directory: .+schema.json", six.text_type(e)):
+    if re.search("No such file or directory: .+schema.json", str(e)):
         raise RuntimeError(
             "ipynb file format conversion not supported for the binary version. "
             "please try to install sqlitebiter via pip."
         )
 
 
-def make_requests_session(retries=5, status_forcelist=(500, 502, 504)):
-    from requests.adapters import HTTPAdapter
-    from requests.packages.urllib3.util.retry import Retry
-    from requests import Session
-
-    session = Session()
-    adapter = HTTPAdapter(
-        max_retries=Retry(
-            total=retries,
-            read=retries,
-            connect=retries,
-            backoff_factor=0.5,
-            status_forcelist=status_forcelist,
-        )
-    )
-    session.mount("http://", adapter)
-    session.mount("https://", adapter)
-
-    return session
-
-
 def load_ipynb_file(file_path, encoding):
-    with io.open(file_path, encoding=encoding) as f:
+    with open(file_path, encoding=encoding) as f:
         try:
             return nbformat.read(f, as_version=4)
         except AttributeError as e:
             raise nbformat.reader.NotJSONError(msgfy.to_error_message(e))
-        except IOError as e:
+        except OSError as e:
             _schema_not_found_error_handler(e)
             raise
 
 
 def load_ipynb_url(url, proxies):
-    response = make_requests_session().get(url, proxies=proxies)
+    response = retryrequests.get(url, proxies=proxies)
     response.raise_for_status()
 
     try:
         return (nbformat.reads(response.text, as_version=4), len(response.content))
-    except IOError as e:
+    except OSError as e:
         _schema_not_found_error_handler(e)
         raise
 
 
-class NbAttr(object):
+class NbAttr:
     CELL_ID = "cell_id"
     KEY = "key"
     LINE_NUMBER = "line_no"
@@ -95,7 +65,7 @@ class NbAttr(object):
     VALUE = "value"
 
 
-class NbAttrDesc(object):
+class NbAttrDesc:
     CELL_ID = "{:s} INTEGER NOT NULL".format(NbAttr.CELL_ID)
     KEY = "{:s} TEXT NOT NULL".format(NbAttr.KEY)
     LINE_NUMBER = "{:s} INTEGER NOT NULL".format(NbAttr.LINE_NUMBER)
@@ -103,8 +73,7 @@ class NbAttrDesc(object):
     VALUE = "{:s} TEXT".format(NbAttr.VALUE)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class JupyterNotebookConverterInterface(object):
+class JupyterNotebookConverterInterface(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def convert(self):  # pragma: no cover
         pass
@@ -124,7 +93,7 @@ class JupyterNotebookConverterBase(JupyterNotebookConverterInterface):
         self._source_info = source_info
         self._con = con
         self._result_logger = result_logger
-        self._changed_table_name_set = set([])
+        self._changed_table_name_set = set()
 
     def _get_log_header(self, info_name):
         return "{:s}: {:s}({:s})".format(
@@ -148,7 +117,7 @@ class MetaDataConverter(JupyterNotebookConverterBase):
         return "metadata"
 
     def __init__(self, logger, source_info, con, result_logger, metadata):
-        super(MetaDataConverter, self).__init__(logger, source_info, con, result_logger)
+        super().__init__(logger, source_info, con, result_logger)
 
         self.__metadata = metadata
 
@@ -250,7 +219,7 @@ class CellConverter(JupyterNotebookConverterBase):
         return "cells"
 
     def __init__(self, logger, source_info, con, result_logger, cells):
-        super(CellConverter, self).__init__(logger, source_info, con, result_logger)
+        super().__init__(logger, source_info, con, result_logger)
 
         self.__cells = cells
         self._cell_id = None
@@ -301,7 +270,7 @@ class CellConverter(JupyterNotebookConverterBase):
                 if not value:
                     record = (self.source_id, self._cell_id, key, None)
                 else:
-                    record = (self.source_id, self._cell_id, key, six.text_type(dict(value)))
+                    record = (self.source_id, self._cell_id, key, str(dict(value)))
 
                 record_list.append(record)
                 continue
@@ -444,7 +413,7 @@ class CellConverter(JupyterNotebookConverterBase):
 
 
 def convert_nb(logger, source_info, con, result_logger, nb):
-    changed_table_name_set = set([])
+    changed_table_name_set = set()
     changed_table_name_set |= CellConverter(
         logger, source_info, con, result_logger, nb.cells
     ).convert()
