@@ -1,10 +1,7 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import os.path
 
@@ -36,7 +33,7 @@ class SourceInfo(Model):
         return os.path.join(self.dir_name, self.base_name)
 
 
-class TableConverter(object):
+class TableConverter:
     def __init__(
         self,
         logger,
@@ -207,7 +204,7 @@ class TableConverter(object):
         )
 
         if self._result_counter.success_count == success_count:
-            self._logger.warn(TABLE_NOT_FOUND_MSG_FORMAT.format(source_info.base_name))
+            self._logger.warning(TABLE_NOT_FOUND_MSG_FORMAT.format(source_info.base_name))
             return
 
         return created_table_set
