@@ -1,25 +1,20 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import errno
 import os
 import re
 import sys
 from copy import deepcopy
+from urllib.parse import urlparse
 
 import msgfy
 import pytablereader as ptr
 import simplesqlite as sqlite
-import six
-from six.moves.urllib.parse import urlparse
 
-from .._const import IPYNB_FORMAT_NAME_LIST, TABLE_NOT_FOUND_MSG_FORMAT
-from .._enum import ExitCode
+from .._const import IPYNB_FORMAT_NAME_LIST, TABLE_NOT_FOUND_MSG_FORMAT, ExitCode
 from .._ipynb_converter import is_ipynb_url, load_ipynb_url
 from ._base import SourceInfo, TableConverter
 from ._common import TYPE_HINT_FROM_HEADER_RULES, normalize_type_hint
@@ -68,7 +63,7 @@ class UrlConverter(TableConverter):
         encoding,
         proxy,
     ):
-        super(UrlConverter, self).__init__(
+        super().__init__(
             logger,
             con,
             symbol_replace_value=symbol_replace_value,
@@ -115,7 +110,7 @@ class UrlConverter(TableConverter):
 
         try:
             for table_data in loader.load():
-                logger.debug("loaded table_data: {}".format(six.text_type(table_data)))
+                logger.debug("loaded table_data: {}".format(str(table_data)))
 
                 sqlite_tabledata = self.normalize_table(table_data)
 
@@ -159,7 +154,7 @@ class UrlConverter(TableConverter):
             result_counter.inc_fail()
 
         if result_counter.success_count == success_count:
-            logger.warn(TABLE_NOT_FOUND_MSG_FORMAT.format(url))
+            logger.warning(TABLE_NOT_FOUND_MSG_FORMAT.format(url))
 
     def __get_proxies(self):
         return {"http": self.__proxy, "https": self.__proxy}
@@ -196,7 +191,7 @@ class UrlConverter(TableConverter):
             if config.get("target_url") not in url:
                 continue
 
-            for pattern, params in six.iteritems(config.get("rules")):
+            for pattern, params in config.get("rules").items():
                 if not params.get("type hint"):
                     continue
 
