@@ -1,18 +1,15 @@
-# encoding: utf-8
-
-from __future__ import print_function
-
 import re
 
 import pytest
 from click.testing import CliRunner
-from sqlitebiter._enum import ExitCode
+
+from sqlitebiter._const import ExitCode
 from sqlitebiter.sqlitebiter import cmd
 
 from .common import print_test_result, print_traceback
 
 
-class Test_sqlitebiter_completion(object):
+class Test_sqlitebiter_completion:
     @pytest.mark.parametrize(
         ["shell", "expected"], [["bash", ExitCode.SUCCESS], ["zsh", ExitCode.SUCCESS]]
     )
