@@ -1,15 +1,14 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
 import pytest
+
+from sqlitebiter._const import ExitCode
 from sqlitebiter._counter import ResultCounter
-from sqlitebiter._enum import ExitCode
 
 
-class Test_ResultCounter(object):
+class Test_ResultCounter:
     @pytest.mark.parametrize(
         ["success", "fail", "expected"],
         [
